'use strict';

const { getData, postJSON } = require('peer-wechat-api/lib/util');

/**
 * 新建草稿
 * @param {array} articles 文章列表
 */
exports.addDraft = async function (articles) {
  const { accessToken } = await this.ensureAccessToken();
  // https://api.weixin.qq.com/cgi-bin/draft/add?access_token=ACCESS_TOKEN
  var url = this.prefix + 'draft/add?access_token=' + accessToken;
  var data = {};
  data.articles = articles
  return this.request(url, postJSON(data));
};

/**
 * 获取草稿
 * @param {string} mediaID 草稿的media_id
 */
 exports.getDraft = async function (mediaID) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/draft/get?access_token=ACCESS_TOKEN
    var url = this.prefix + 'draft/get?access_token=' + accessToken;
    var data = {};
    data.media_id = mediaID
    return this.request(url, postJSON(data));
};

/**
 * 获取草稿总数
 */
 exports.countDraft = async function () {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/draft/count?access_token=ACCESS_TOKEN
    var url = this.prefix + 'draft/count?access_token=' + accessToken;
    return this.request(url, getData());
};

/**
 * 获取草稿的列表
 * @param {number} offset 从全部素材的该偏移位置开始返回，0表示从第一个素材返回
 * @param {number} count 返回素材的数量，取值在1到20之间
 * @param {number} no_content 1 表示不返回 content 字段，0 表示正常返回，默认为 0
 */
 exports.batchGetDraft = async function (offset, count = 20, no_content = 0) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/draft/batchget?access_token=ACCESS_TOKEN
    var url = this.prefix + 'draft/batchget?access_token=' + accessToken;
    var data = {
        offset: offset,
        count: count,
        no_content: no_content,
    };
    return this.request(url, postJSON(data));
};

/**
 * 删除草稿
 * @param {string} mediaID 草稿的media_id
 */
 exports.deleteDraft = async function (mediaID) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/draft/delete?access_token=ACCESS_TOKEN
    var url = this.prefix + 'draft/delete?access_token=' + accessToken;
    var data = {};
    data.media_id = mediaID
    return this.request(url, postJSON(data));
};

/**
 * 批量获取发布的文章
 * @param {string} articleID 文章的article_id
 * @param {number} index 要删除的文章在图文消息中的位置，第一篇编号为1，该字段不填或填0会删除全部文章
 */
 exports.freePublishBatchget = async function (offset, count = 20, noContent = 1) {
    const { accessToken } = await this.ensureAccessToken();
    var url = this.prefix + 'freepublish/batchget?access_token=' + accessToken;
    var data = {
        offset: offset,
        count: count,
        no_content: noContent,
    };
    return this.request(url, postJSON(data));
};

/**
 * 发布的草稿
 * @param {string} mediaID 草稿的media_id
 */
 exports.freePublishSubmit = async function (mediaID) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/freepublish/submit?access_token=ACCESS_TOKEN
    var url = this.prefix + 'freepublish/submit?access_token=' + accessToken;
    var data = {};
    data.media_id = mediaID
    return this.request(url, postJSON(data));
};

/**
 * 发布文章的状态
 * @param {string} publishID 草稿的publish_id
 */
 exports.freePublishGet = async function (publishID) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/freepublish/get?access_token=ACCESS_TOKEN
    var url = this.prefix + 'freepublish/get?access_token=' + accessToken;
    var data = {};
    data.publish_id = publishID
    return this.request(url, postJSON(data));
};

/**
 * 删除发布的文章
 * @param {string} articleID 文章的article_id
 * @param {number} index 要删除的文章在图文消息中的位置，第一篇编号为1，该字段不填或填0会删除全部文章
 */
 exports.freePublishDelete = async function (articleID, index = 0) {
    const { accessToken } = await this.ensureAccessToken();
    // https://api.weixin.qq.com/cgi-bin/freepublish/delete?access_token=ACCESS_TOKEN
    var url = this.prefix + 'freepublish/delete?access_token=' + accessToken;
    var data = {
        article_id: articleID,
        index: index,
    };
    return this.request(url, postJSON(data));
};
